@@ -443,6 +443,19 @@ class DemurrageToken(ERC20, SealedContract, ExpiryContract):
         return tx
 
 
+    def sweep(self, contract_address, sender_address, recipient_address, tx_format=TxFormat.JSONRPC):
+        enc = ABIContractEncoder()
+        enc.method('sweep')
+        enc.typ(ABIContractType.ADDRESS)
+        enc.address(recipient_address)
+        data = enc.get()
+        tx = self.template(sender_address, contract_address, use_nonce=True)
+        tx = self.set_code(tx, data)
+        tx = self.finalize(tx, tx_format)
+        return tx
+
+
+
     def apply_demurrage(self, contract_address, sender_address, limit=0, tx_format=TxFormat.JSONRPC):
         if limit == 0:
             return self.transact_noarg('applyDemurrage', contract_address, sender_address)
@@ -474,10 +487,8 @@ class DemurrageToken(ERC20, SealedContract, ExpiryContract):
         return tx
 
 
-
-
-    def tax_level(self, contract_address, sender_address=ZERO_ADDRESS):
-        return self.call_noarg('taxLevel', contract_address, sender_address=sender_address)
+    def decay_level(self, contract_address, sender_address=ZERO_ADDRESS):
+        return self.call_noarg('decayLevel', contract_address, sender_address=sender_address)
 
 
     def resolution_factor(self, contract_address, sender_address=ZERO_ADDRESS):
@@ -658,7 +669,7 @@ class DemurrageToken(ERC20, SealedContract, ExpiryContract):
 
 
     @classmethod
-    def parse_tax_level(self, v):
+    def parse_decay_level(self, v):
         return abi_decode_single(ABIContractType.UINT256, v)
 
 
